@@ -1,6 +1,5 @@
 from qbittorrentapi.app import AppAPIMixIn
 from qbittorrentapi.decorators import login_required
-from qbittorrentapi.decorators import response_json
 from qbittorrentapi.definitions import APINames
 from qbittorrentapi.definitions import ClientCache
 from qbittorrentapi.definitions import List
@@ -10,9 +9,9 @@ from qbittorrentapi.definitions import ListEntry
 class LogPeersList(List):
     """Response for :meth:`~LogAPIMixIn.log_peers`"""
 
-    def __init__(self, list_entries=None, client=None):
+    def __init__(self, list_entries, client):
         super(LogPeersList, self).__init__(
-            list_entries, entry_class=LogPeer, client=client
+            client=client, entry_class=LogPeer, list_entries=list_entries
         )
 
 
@@ -23,9 +22,9 @@ class LogPeer(ListEntry):
 class LogMainList(List):
     """Response to :meth:`~LogAPIMixIn.log_main`"""
 
-    def __init__(self, list_entries=None, client=None):
+    def __init__(self, list_entries, client):
         super(LogMainList, self).__init__(
-            list_entries, entry_class=LogEntry, client=client
+            client=client, entry_class=LogEntry, list_entries=list_entries
         )
 
 
@@ -138,7 +137,6 @@ class LogAPIMixIn(AppAPIMixIn):
             self._log = Log(client=self)
         return self._log
 
-    @response_json(LogMainList)
     @login_required
     def log_main(
         self,
@@ -167,10 +165,13 @@ class LogAPIMixIn(AppAPIMixIn):
             "last_known_id": last_known_id,
         }
         return self._get(
-            _name=APINames.Log, _method="main", params=parameters, **kwargs
+            _name=APINames.Log,
+            _method="main",
+            params=parameters,
+            response_class=LogMainList,
+            **kwargs
         )
 
-    @response_json(LogPeersList)
     @login_required
     def log_peers(self, last_known_id=None, **kwargs):
         """
@@ -181,5 +182,9 @@ class LogAPIMixIn(AppAPIMixIn):
         """
         parameters = {"last_known_id": last_known_id}
         return self._get(
-            _name=APINames.Log, _method="peers", params=parameters, **kwargs
+            _name=APINames.Log,
+            _method="peers",
+            params=parameters,
+            response_class=LogPeersList,
+            **kwargs
         )
